# LASER embeddings

**This project is a fork of [https://github.com/yannvgn/laserembeddings](https://github.com/yannvgn/laserembeddings) with minimal changes.**

✨ **Version 1.2.0. What's new?**
- increased minimal version of Torch, Sacremoses and Python in .toml file

![LASER embeddings maps similar sentences in any language to similar language-agnostic embeddings](laserembeddings.gif)

_laserembeddings_ is a pip-packaged, production-ready port of Facebook Research's [LASER](https://github.com/facebookresearch/LASER) (Language-Agnostic SEntence Representations) to compute multilingual sentence embeddings.

If you want to see full version of description, please go to the original project homepage : [https://github.com/yannvgn/laserembeddings](https://github.com/yannvgn/laserembeddings).
